@@ -1,6 +1,4 @@
 # Published Jan 2013
-# Revised Jan 2014 (to add new modules data)
-# Revised 2016 (to add camera support)
 # Author : Philippe Larduinat, ph.larduinat@wanadoo.fr
 # Multiple contributors : see https://github.com/philippelt/netatmo-api-python
 # License : GPL V3
@@ -15,17 +13,24 @@ coding=utf-8
 from sys import version_info
 from os import getenv
 from os.path import expanduser, exists
+import platform
+import warnings
 import json, time
 import imghdr
 import warnings
+import logging
+
+# Just in case method could change
+PYTHON3 = (version_info.major > 2)
 
 # HTTP libraries depends upon Python 2 or 3
-if version_info.major == 3 :
+if PYTHON3 :
     import urllib.parse, urllib.request
 else:
     from urllib import urlencode
     import urllib2
 
+
 ######################## AUTHENTICATION INFORMATION ######################
 
 # To be able to have a program accessing your netatmo data, you have to register your program as
@@ -38,15 +43,18 @@ else:
 #  1 - Values hard coded in the library
 #  2 - The .netatmo.credentials file in JSON format in your home directory
 #  3 - Values defined in environment variables : CLIENT_ID, CLIENT_SECRET, USERNAME, PASSWORD
+#      Note: The USERNAME environment variable may interfer with the envvar used by Windows for login name
+#            if you have this issue, do not forget to "unset USERNAME" before running your program
 
 # Each level override values defined in the previous level. You could define CLIENT_ID and CLIENT_SECRET hard coded in the library
 # and username/password in .netatmo.credentials or environment variables
 
-cred = {                       # You can hard code authentication information in the following lines
-        "CLIENT_ID" :  "",     #   Your client ID from Netatmo app registration at http://dev.netatmo.com/dev/listapps
-        "CLIENT_SECRET" : "",  #   Your client app secret   '     '
-        "USERNAME" : "",       #   Your netatmo account username
-        "PASSWORD" : ""        #   Your netatmo account password
+# 1 : Embedded credentials
+cred = {                           # You can hard code authentication information in the following lines
+        "CLIENT_ID" :  "",         #   Your client ID from Netatmo app registration at http://dev.netatmo.com/dev/listapps
+        "CLIENT_SECRET" : "",      #   Your client app secret   '     '
+        "USERNAME" : "",           #   Your netatmo account username
+        "PASSWORD" : ""            #   Your netatmo account password
         }
 
 # Other authentication setup management (optionals)
@@ -58,9 +66,17 @@ def getParameter(key, default):
 
 # 2 : Override hard coded values with credentials file if any
 if exists(CREDENTIALS) :
-    with open(CREDENTIALS, "r") as f: cred = json.loads(f.read())
+    with open(CREDENTIALS, "r") as f:
+        cred.update({k.upper():v for k,v in json.loads(f.read()).items()})
 
 # 3 : Override final value with content of env variables if defined
+#     Warning, for Windows user, USERNAME contains by default the windows logged user name
+#     This usually lead to an authentication error
+if platform.system() == "Windows" and getenv("USERNAME", None):
+    warnings.warn("You are running on Windows and the USERNAME env var is set. " \
+                  "Be sure this env var contains Your Netatmo username " \
+                  "or clear it with <SET USERNAME=> before running your program\n", RuntimeWarning, stacklevel=3)
+
 _CLIENT_ID     = getParameter("CLIENT_ID", cred)
 _CLIENT_SECRET = getParameter("CLIENT_SECRET", cred)
 _USERNAME      = getParameter("USERNAME", cred)
@@ -72,19 +88,78 @@ _PASSWORD      = getParameter("PASSWORD", cred)
 # Common definitions
 
 _BASE_URL = "https://api.netatmo.com/"
-_AUTH_REQ             = _BASE_URL + "oauth2/token"
-_GETMEASURE_REQ       = _BASE_URL + "api/getmeasure"
-_GETSTATIONDATA_REQ   = _BASE_URL + "api/getstationsdata"
-_GETHOMEDATA_REQ      = _BASE_URL + "api/gethomedata"
-_GETCAMERAPICTURE_REQ = _BASE_URL + "api/getcamerapicture"
-_GETEVENTSUNTIL_REQ   = _BASE_URL + "api/geteventsuntil"
+_AUTH_REQ              = _BASE_URL + "oauth2/token"
+_GETMEASURE_REQ        = _BASE_URL + "api/getmeasure"
+_GETSTATIONDATA_REQ    = _BASE_URL + "api/getstationsdata"
+_GETTHERMOSTATDATA_REQ = _BASE_URL + "api/getthermostatsdata"
+_GETHOMEDATA_REQ       = _BASE_URL + "api/gethomedata"
+_GETCAMERAPICTURE_REQ  = _BASE_URL + "api/getcamerapicture"
+_GETEVENTSUNTIL_REQ    = _BASE_URL + "api/geteventsuntil"
 
 
+#TODO# Undocumented (but would be very usefull) API : Access currently forbidden (403)
+
+# _POST_UPDATE_HOME_REQ  = _BASE_URL + "/api/updatehome"
+
+# For presence setting (POST BODY):
+# _PRES_BODY_REC_SET     = "home_id=%s&presence_settings[presence_record_%s]=%s"   # (HomeId, DetectionKind, DetectionSetup.index)
+_PRES_DETECTION_KIND   = ("humans", "animals", "vehicles", "movements")
+_PRES_DETECTION_SETUP  = ("ignore", "record", "record & notify")
+
+# _PRES_BODY_ALERT_TIME  = "home_id=%s&presence_settings[presence_notify_%s]=%s"   # (HomeID, "from"|"to", "hh:mm")
+
+# Regular (documented) commands (both cameras)
+
+_PRES_CDE_GET_SNAP     = "/live/snapshot_720.jpg"
+
+#TODO# Undocumented (taken from https://github.com/KiboOst/php-NetatmoCameraAPI/blob/master/class/NetatmoCameraAPI.php)
+# Work with local_url only (undocumented scope control probably)
+
+# For Presence camera
+
+_PRES_CDE_GET_LIGHT    = "/command/floodlight_get_config"
+# Not working yet, probably due to scope restriction
+#_PRES_CDE_SET_LIGHT    = "/command/floodlight_set_config?config=mode:%s"    # "auto"|"on"|"off"
+
+
+# For all cameras
+
+_CAM_CHANGE_STATUS     = "/command/changestatus?status=%s"            # "on"|"off"
+# Not working yet
+#_CAM_FTP_ACTIVE        = "/command/ftp_set_config?config=on_off:%s"   # "on"|"off"
+
+# UNITS used by Netatmo services
+UNITS = {
+    "unit" : {
+        0: "metric",
+        1: "imperial"
+    },
+    "windunit" : {
+        0: "kph",
+        1: "mph",
+        2: "ms",
+        3: "beaufort",
+        4: "knot"
+    },
+    "pressureunit" : {
+        0: "mbar",
+        1: "inHg",
+        2: "mmHg"
+    }
+}
+
+# Logger context
+logger = logging.getLogger("lnetatmo")
+
 
 class NoDevice( Exception ):
     pass
 
 
+class AuthFailure( Exception ):
+    pass
+
+
 class ClientAuth:
     """
     Request authentication and keep access token available through token method. Renew it automatically if necessary
@@ -105,7 +180,8 @@ class ClientAuth:
                        clientSecret=_CLIENT_SECRET,
                        username=_USERNAME,
                        password=_PASSWORD,
-                       scope="read_station"):
+                       scope="read_station read_camera access_camera write_camera " \
+                                 "read_presence access_presence write_presence read_thermostat write_thermostat"):
         
         postParams = {
                 "grant_type" : "password",
@@ -116,6 +192,8 @@ class ClientAuth:
                 "scope" : scope
                 }
         resp = postRequest(_AUTH_REQ, postParams)
+        if not resp: raise AuthFailure("Authentication request rejected")
+
         self._clientId = clientId
         self._clientSecret = clientSecret
         self._accessToken = resp['access_token']
@@ -147,6 +225,8 @@ class User:
     Args:
         authData (ClientAuth): Authentication information with a working access Token
     """
+    warnings.warn("The 'User' class is no longer maintained by Netatmo",
+            DeprecationWarning )
     def __init__(self, authData):
         postParams = {
                 "access_token" : authData.accessToken
@@ -156,6 +236,62 @@ class User:
         self.devList = self.rawData['devices']
         self.ownerMail = self.rawData['user']['mail']
 
+
+class UserInfo:
+    """
+    This class is populated with data from various Netatmo requests to provide
+    complimentary data (eg Units for Weatherdata)
+    """
+    pass
+
+
+class ThermostatData:
+    """
+    List the Thermostat and temperature modules
+
+    Args:
+        authData (clientAuth): Authentication information with a working access Token
+    """
+    def __init__(self, authData):
+        self.getAuthToken = authData.accessToken
+        postParams = {
+                "access_token" : self.getAuthToken
+                }
+        resp = postRequest(_GETTHERMOSTATDATA_REQ, postParams)
+        self.rawData = resp['body']['devices']
+        if not self.rawData : raise NoDevice("No thermostat available")
+        self.thermostat = { d['_id'] : d for d in self.rawData }
+        for t,v in self.thermostat.items():
+            v['name'] = v['station_name']
+            for m in v['modules']:
+                m['name'] = m['module_name']
+        self.defaultThermostat = self.rawData[0]['station_name']
+        self.defaultThermostatId = self.rawData[0]['_id']
+        self.defaultModule = self.rawData[0]['modules'][0]
+
+    def getThermostat(self, name=None, tid=None):
+        if tid:
+            if tid in self.thermostat.keys():
+                return self.thermostat[tid]
+            else:
+                return None
+        elif name:
+            for t in self.thermostat.values():
+                if t['name'] == name: return t
+            return None
+        return self.thermostat[self.defaultThermostatId]
+
+    def moduleNamesList(self, name=None, tid=None):
+        thermostat = self.getThermostat(name=name, tid=tid)
+        return [m['name'] for m in thermostat['modules']] if thermostat else None
+
+    def getModuleByName(self, name, thermostatId=None):
+        thermostat = self.getThermostat(tid=thermostatId)
+        for m in thermostat['modules']:
+            if m['name'] == name: return m
+        return None
+
+
 class WeatherStationData:
     """
     List the Weather Station devices (stations and modules)
@@ -170,13 +306,26 @@ class WeatherStationData:
                 }
         resp = postRequest(_GETSTATIONDATA_REQ, postParams)
         self.rawData = resp['body']['devices']
+        # Weather data
         if not self.rawData : raise NoDevice("No weather station available")
         self.stations = { d['_id'] : d for d in self.rawData }
         self.modules = dict()
         for i in range(len(self.rawData)):
-            for m in self.rawData[i]['modules']:
-                self.modules[ m['_id'] ] = m
+            # Loop on external modules if they are present
+            if 'modules' in self.rawData[i]:
+                for m in self.rawData[i]['modules']:
+                    self.modules[ m['_id'] ] = m
         self.default_station = list(self.stations.values())[0]['station_name']
+        # User data
+        userData = resp['body']['user']
+        self.user = UserInfo()
+        setattr(self.user, "mail", userData['mail'])
+        for k,v in userData['administrative'].items():
+            if k in UNITS:
+                setattr(self.user, k, UNITS[k][v])
+            else:
+                setattr(self.user, k, v)
+
 
     def modulesNamesList(self, station=None):
         res = [m['module_name'] for m in self.modules.values()]
@@ -215,24 +364,30 @@ class WeatherStationData:
                 return self.modules[mid]
 
     def lastData(self, station=None, exclude=0):
-        s = self.stationByName(station)
-        if not s : return None
+        s = self.stationByName(station) or self.stationById(station)
+        # Breaking change from Netatmo : dashboard_data no longer available if station lost
+        if not s or 'dashboard_data' not in s : return None
         lastD = dict()
         # Define oldest acceptable sensor measure event
         limit = (time.time() - exclude) if exclude else 0
         ds = s['dashboard_data']
-        if ds['time_utc'] > limit :
+        if ds.get('time_utc',limit+10) > limit :
             lastD[s['module_name']] = ds.copy()
-            lastD[s['module_name']]['When'] = lastD[s['module_name']].pop("time_utc")
+            lastD[s['module_name']]['When'] = lastD[s['module_name']].pop("time_utc") if 'time_utc' in lastD[s['module_name']] else time.time()
             lastD[s['module_name']]['wifi_status'] = s['wifi_status']
-        for module in s["modules"]:
-            ds = module['dashboard_data']
-            if ds['time_utc'] > limit :
-                lastD[module['module_name']] = ds.copy()
-                lastD[module['module_name']]['When'] = lastD[module['module_name']].pop("time_utc")
-                # For potential use, add battery and radio coverage information to module data if present
-                for i in ('battery_vp', 'rf_status') :
-                    if i in module : lastD[module['module_name']][i] = module[i]
+        if 'modules' in s:
+            for module in s["modules"]:
+                # Skip lost modules that no longer have dashboard data available
+                if 'dashboard_data' not in module : continue
+                ds = module['dashboard_data']
+                if ds.get('time_utc',limit+10) > limit :
+                    # If no module_name has been setup, use _id by default
+                    if "module_name" not in module : module['module_name'] = module["_id"]
+                    lastD[module['module_name']] = ds.copy()
+                    lastD[module['module_name']]['When'] = lastD[module['module_name']].pop("time_utc") if 'time_utc' in lastD[module['module_name']] else time.time()
+                    # For potential use, add battery and radio coverage information to module data if present
+                    for i in ('battery_vp', 'battery_percent', 'rf_status') :
+                        if i in module : lastD[module['module_name']][i] = module[i]
         return lastD
 
     def checkNotUpdated(self, station=None, delay=3600):
@@ -308,9 +463,9 @@ class DeviceList(WeatherStationData):
             DeprecationWarning )
     pass
 
-class WelcomeData:
+class HomeData:
     """
-    List the Netatmo Welcome cameras informations (Homes, cameras, events, persons)
+    List the Netatmo home informations (Homes, cameras, events, persons)
 
     Args:
         authData (ClientAuth): Authentication information with a working access Token
@@ -322,27 +477,35 @@ class WelcomeData:
             }
         resp = postRequest(_GETHOMEDATA_REQ, postParams)
         self.rawData = resp['body']
+        # Collect homes
         self.homes = { d['id'] : d for d in self.rawData['homes'] }
-        if not self.homes : raise NoDevice("No camera available")
+        if not self.homes : raise NoDevice("No home available")
+        self.default_home = list(self.homes.values())[0]['name']
+        # Split homes data by category
         self.persons = dict()
         self.events = dict()
         self.cameras = dict()
         self.lastEvent = dict()
         for i in range(len(self.rawData['homes'])):
-            nameHome=self.rawData['homes'][i]['name']
+            curHome = self.rawData['homes'][i]
+            nameHome = curHome['name']
             if nameHome not in self.cameras:
-                self.cameras[nameHome]=dict()
-            for p in self.rawData['homes'][i]['persons']:
-                self.persons[ p['id'] ] = p
-            for e in self.rawData['homes'][i]['events']:
-                if e['camera_id'] not in self.events:
-                    self.events[ e['camera_id'] ] = dict()
-                self.events[ e['camera_id'] ][ e['time'] ] = e
-            for c in self.rawData['homes'][i]['cameras']:
-                self.cameras[nameHome][ c['id'] ] = c
+                self.cameras[nameHome] = dict()
+            if 'persons' in curHome:
+                for p in curHome['persons']:
+                    self.persons[ p['id'] ] = p
+            if 'events' in curHome:
+                    for e in curHome['events']:
+                        if e['camera_id'] not in self.events:
+                            self.events[ e['camera_id'] ] = dict()
+                        self.events[ e['camera_id'] ][ e['time'] ] = e
+            if 'cameras' in curHome:
+                for c in curHome['cameras']:
+                    self.cameras[nameHome][ c['id'] ] = c
+                    c["home_id"] = curHome['id']
         for camera in self.events:
-            self.lastEvent[camera]=self.events[camera][sorted(self.events[camera])[-1]]
-        self.default_home = list(self.homes.values())[0]['name']
+            self.lastEvent[camera] = self.events[camera][sorted(self.events[camera])[-1]]
+        if not self.cameras[self.default_home] : raise NoDevice("No camera available in default home")
         self.default_camera = list(self.cameras[self.default_home].values())[0]
 
     def homeById(self, hid):
@@ -382,6 +545,8 @@ class WelcomeData:
         """
         Return the vpn_url and the local_url (if available) of a given camera
         in order to access to its live feed
+        Can't use the is_local property which is mostly false in case of operator
+        dynamic IP change after presence start sequence
         """
         local_url = None
         vpn_url = None
@@ -391,14 +556,21 @@ class WelcomeData:
             camera_data=self.cameraByName(camera=camera, home=home)
         if camera_data:
             vpn_url = camera_data['vpn_url']
-            if camera_data['is_local']:
-                resp = postRequest('{0}/command/ping'.format(camera_data['vpn_url']),dict())
-                temp_local_url=resp['local_url']
-                resp = postRequest('{0}/command/ping'.format(temp_local_url),dict())
-                if temp_local_url == resp['local_url']:
+            resp = postRequest(vpn_url + '/command/ping')
+            temp_local_url=resp['local_url']
+            try:
+                resp = postRequest(temp_local_url + '/command/ping',timeout=1)
+                if resp and temp_local_url == resp['local_url']:
                     local_url = temp_local_url
+            except:  # On this particular request, vithout errors from previous requests, error is timeout
+                local_url = None
         return vpn_url, local_url
 
+    def url(self, camera=None, home=None, cid=None):
+        vpn_url, local_url = self.cameraUrls(camera, home, cid)
+        # Return local if available else vpn
+        return local_url or vpn_url
+
     def personsAtHome(self, home=None):
         """
         Return the list of known persons who are currently at home
@@ -422,7 +594,7 @@ class WelcomeData:
             "image_id" : image_id,
             "key" : key
             }
-        resp = postRequest(_GETCAMERAPICTURE_REQ, postParams, json_resp=False, body_size=None)
+        resp = postRequest(_GETCAMERAPICTURE_REQ, postParams)
         image_type = imghdr.what('NONE.FILE',resp)
         return resp, image_type
 
@@ -470,7 +642,7 @@ class WelcomeData:
         try:
             cam_id = self.cameraByName(camera=camera, home=home)['id']
         except TypeError:
-            print("personSeenByCamera: Camera name or home is unknown")
+            logger.warning("personSeenByCamera: Camera name or home is unknown")
             return False
         #Check in the last event is someone known has been seen
         if self.lastEvent[cam_id]['type'] == 'person':
@@ -494,7 +666,7 @@ class WelcomeData:
         try:
             cam_id = self.cameraByName(camera=camera, home=home)['id']
         except TypeError:
-            print("personSeenByCamera: Camera name or home is unknown")
+            logger.warning("personSeenByCamera: Camera name or home is unknown")
             return False
         #Check in the last event is someone known has been seen
         if self.lastEvent[cam_id]['type'] == 'person':
@@ -509,7 +681,7 @@ class WelcomeData:
         try:
             cam_id = self.cameraByName(camera=camera, home=home)['id']
         except TypeError:
-            print("personSeenByCamera: Camera name or home is unknown")
+            logger.warning("personSeenByCamera: Camera name or home is unknown")
             return False
         #Check in the last event is someone known has been seen
         if self.lastEvent[cam_id]['type'] == 'person':
@@ -524,30 +696,94 @@ class WelcomeData:
         try:
             cam_id = self.cameraByName(camera=camera, home=home)['id']
         except TypeError:
-            print("personSeenByCamera: Camera name or home is unknown")
+            logger.warning("personSeenByCamera: Camera name or home is unknown")
             return False
         if self.lastEvent[cam_id]['type'] == 'movement':
             return True
         return False
 
+    def presenceUrl(self, camera=None, home=None, cid=None, setting=None):
+        camera = self.cameraByName(home=home, camera=camera) or self.cameraById(cid=cid)
+        if camera["type"] != "NOC": return None # Not a presence camera
+        vpnUrl, localUrl = self.cameraUrls(cid=camera["id"])
+        return localUrl
+    
+    def presenceLight(self, camera=None, home=None, cid=None, setting=None):
+        url = self.presenceUrl(home=home, camera=camera) or self.cameraById(cid=cid)
+        if not url or setting not in ("on", "off", "auto"): return None
+        if setting : return "Currently unsupported"
+        return cameraCommand(url, _PRES_CDE_GET_LIGHT)["mode"]
+        # Not yet supported
+        #if not setting: return cameraCommand(url, _PRES_CDE_GET_LIGHT)["mode"]
+        #else: return cameraCommand(url, _PRES_CDE_SET_LIGHT, setting)
+
+    def presenceStatus(self, mode, camera=None, home=None, cid=None):
+        url = self.presenceUrl(home=home, camera=camera) or self.cameraById(cid=cid)
+        if not url or mode not in ("on", "off") : return None
+        r = cameraCommand(url, _CAM_CHANGE_STATUS, mode)
+        return mode if r["status"] == "ok" else None
+
+    def presenceSetAction(self, camera=None, home=None, cid=None,
+                          eventType=_PRES_DETECTION_KIND[0], action=2):
+        return "Currently unsupported"
+        if eventType not in _PRES_DETECTION_KIND or \
+           action not in _PRES_DETECTION_SETUP : return None
+        camera = self.cameraByName(home=home, camera=camera) or self.cameraById(cid=cid)
+        postParams = { "access_token" : self.getAuthToken,
+                       "home_id" : camera["home_id"],
+                       "presence_settings[presence_record_%s]" % eventType : _PRES_DETECTION_SETUP.index(action)
+                     }
+        resp = postRequest(_POST_UPDATE_HOME_REQ, postParams)
+        self.rawData = resp['body']
+
+    def getLiveSnapshot(self, camera=None, home=None, cid=None):
+        camera = self.cameraByName(home=home, camera=camera) or self.cameraById(cid=cid)
+        vpnUrl, localUrl = self.cameraUrls(cid=camera["id"])
+        url = localUrl or vpnUrl
+        return cameraCommand(url, _PRES_CDE_GET_SNAP)
+
+
+class WelcomeData(HomeData):
+    """
+    This class is now deprecated. Use HomeData instead
+    Home can handle many devices, not only Welcome cameras
+    """
+    warnings.warn("The 'WelcomeData' class was renamed 'HomeData' to handle new Netatmo Home capabilities",
+            DeprecationWarning )
+    pass
+
 # Utilities routines
 
-def postRequest(url, params, json_resp=True, body_size=65535):
-    # Netatmo response body size limited to 64k (should be under 16k)
-    if version_info.major == 3:
+def cameraCommand(cameraUrl, commande, parameters=None, timeout=3):
+    url = cameraUrl + ( commande % parameters if parameters else commande)
+    return postRequest(url, timeout=timeout)
+    
+def postRequest(url, params=None, timeout=10):
+    if PYTHON3:
         req = urllib.request.Request(url)
-        req.add_header("Content-Type","application/x-www-form-urlencoded;charset=utf-8")
-        params = urllib.parse.urlencode(params).encode('utf-8')
-        resp = urllib.request.urlopen(req, params).read(body_size).decode("utf-8")
+        if params:
+            req.add_header("Content-Type","application/x-www-form-urlencoded;charset=utf-8")
+            params = urllib.parse.urlencode(params).encode('utf-8')
+        try:
+            resp = urllib.request.urlopen(req, params, timeout=timeout) if params else urllib.request.urlopen(req, timeout=timeout)
+        except urllib.error.HTTPError as err:
+            logger.error("code=%s, reason=%s" % (err.code, err.reason))
+            return None
     else:
-        params = urlencode(params)
-        headers = {"Content-Type" : "application/x-www-form-urlencoded;charset=utf-8"}
-        req = urllib2.Request(url=url, data=params, headers=headers)
-        resp = urllib2.urlopen(req).read(body_size)
-    if json_resp:
-        return json.loads(resp)
-    else:
-        return resp
+        if params:
+            params = urlencode(params)
+            headers = {"Content-Type" : "application/x-www-form-urlencoded;charset=utf-8"}
+        req = urllib2.Request(url=url, data=params, headers=headers) if params else urllib2.Request(url)
+        try:
+            resp = urllib2.urlopen(req, timeout=timeout)
+        except urllib2.HTTPError as err:
+            logger.error("code=%s, reason=%s" % (err.code, err.reason))
+            return None
+    data = b""
+    for buff in iter(lambda: resp.read(65535), b''): data += buff
+    # Return values in bytes if not json data to handle properly camera images
+    returnedContentType = resp.getheader("Content-Type") if PYTHON3 else resp.info()["Content-Type"]
+    return json.loads(data.decode("utf-8")) if "application/json" in returnedContentType else data
 
 def toTimeString(value):
     return time.strftime("%Y-%m-%d_%H:%M:%S", time.localtime(int(value)))
@@ -589,32 +825,34 @@ def getStationMinMaxTH(station=None, module=None):
 if __name__ == "__main__":
 
     from sys import exit, stdout, stderr
+    
+    logging.basicConfig(format='%(name)s - %(levelname)s: %(message)s', level=logging.INFO)
 
     if not _CLIENT_ID or not _CLIENT_SECRET or not _USERNAME or not _PASSWORD :
            stderr.write("Library source missing identification arguments to check lnetatmo.py (user/password/etc...)")
            exit(1)
 
-    authorization = ClientAuth(scope="read_station read_camera access_camera")  # Test authentication method
+    authorization = ClientAuth()  # Test authentication method
     
     try:
-        devList = DeviceList(authorization)         # Test DEVICELIST
+        weatherStation = WeatherStationData(authorization)         # Test DEVICELIST
     except NoDevice:
-        if stdout.isatty():
-            print("lnetatmo.py : warning, no weather station available for testing")
+        logger.warning("No weather station available for testing")
     else:
-        devList.MinMaxTH()                          # Test GETMEASUR
+        weatherStation.MinMaxTH()                          # Test GETMEASUR
 
 
     try:
-        Camera = WelcomeData(authorization)
+        homes = HomeData(authorization)
     except NoDevice :
-        if stdout.isatty():
-            print("lnetatmo.py : warning, no camera available for testing")
+        logger.warning("No home available for testing")
+
+    try:
+        thermostat = ThermostatData(authorization)
+    except NoDevice:
+        logger.warning("No thermostat avaible for testing")
 
     # If we reach this line, all is OK
-
-    # If launched interactively, display OK message
-    if stdout.isatty():
-        print("lnetatmo.py : OK")
+    logger.info("OK")
 
     exit(0)
